@@ -19,11 +19,11 @@ import graphviz
 # -- Project information -----------------------------------------------------
 
 project = 'graphviz'
-copyright = '2013-2022, Sebastian Bank'
+copyright = '2013-2025, Sebastian Bank'
 author = 'Sebastian Bank'
 
 # The full version, including alpha/beta/rc tags
-release = '0.20.1'
+release = '0.21'
 
 
 # -- General configuration ---------------------------------------------------
@@ -71,7 +71,6 @@ on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
 if not on_rtd:
     import sphinx_rtd_theme
     html_theme = 'sphinx_rtd_theme'
-    html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
