@@ -1,9 +1,10 @@
-#!/usr/bin/env python
-# angles.py - http://www.graphviz.org/Gallery/gradient/angles.html
+#!/usr/bin/env python3
 
-from graphviz import Digraph
+"""https://www.graphviz.org/Gallery/gradient/angles.html"""
 
-g = Digraph('G', filename='angles.gv')
+import graphviz
+
+g = graphviz.Digraph('G', filename='angles.gv')
 g.attr(bgcolor='blue')
 
 with g.subgraph(name='cluster_1') as c:
@@ -12,8 +13,8 @@ with g.subgraph(name='cluster_1') as c:
            gradientangle='360', label='n9:360', fontcolor='black')
     c.node('n9')
     for i, a in zip(range(8, 0, -1), range(360 - 45, -1, -45)):
-        c.attr('node', gradientangle='%d' % a, label='n%d:%d' % (i, a))
-        c.node('n%d' % i)
+        c.attr('node', gradientangle=f'{a:d}', label=f'n{i:d}:{a:d}')
+        c.node(f'n{i:d}')
     c.attr(label='Linear Angle Variations (white to black gradient)')
 
 with g.subgraph(name='cluster_2') as c:
@@ -22,8 +23,8 @@ with g.subgraph(name='cluster_2') as c:
            gradientangle='360', label='n18:360', fontcolor='black')
     c.node('n18')
     for i, a in zip(range(17, 9, -1), range(360 - 45, -1, -45)):
-        c.attr('node', gradientangle='%d' % a, label='n%d:%d' % (i, a))
-        c.node('n%d' % i)
+        c.attr('node', gradientangle=f'{a:d}', label=f'n{i:d}:{a:d}')
+        c.node(f'n{i:d}')
     c.attr(label='Radial Angle Variations (white to black gradient)')
 
 g.edge('n5', 'n14')
