@@ -1,9 +1,10 @@
-#!/usr/bin/env python
-# er.py - http://www.graphviz.org/content/ER
+#!/usr/bin/env python3
 
-from graphviz import Graph
+"""https://graphviz.org/Gallery/undirected/ER.html"""
 
-e = Graph('ER', filename='er.gv', engine='neato')
+import graphviz
+
+e = graphviz.Graph('ER', filename='er.gv', engine='neato')
 
 e.attr('node', shape='box')
 e.node('course')
