@@ -210,7 +210,7 @@ def test_save_mocked(mocker, dot, filename='nonfilename', directory='nondirector
     mock_makedirs = mocker.patch('os.makedirs', autospec=True)
     mock_open = mocker.patch('builtins.open', mocker.mock_open())
 
-    with pytest.deprecated_call(match=r'1 positional arg\b'):
+    with pytest.deprecated_call(match=r'\b1 positional arg\b'):
         assert dot.save(filename, directory) == dot.filepath
 
     assert dot.filename == filename
@@ -224,9 +224,16 @@ def test_save_mocked(mocker, dot, filename='nonfilename', directory='nondirector
 
 
 @pytest.mark.exe
-def test_pipe(dot, encoding='utf-8'):
-    svg = dot.pipe(format='svg', encoding=encoding)
-    assert svg.startswith('<?xml ')
+@pytest.mark.parametrize(
+    'plain_text_format, expected_start',
+    [('svg', '<?xml version='),
+     # https://gitlab.com/graphviz/graphviz/-/blob/main/CHANGELOG.md#1001--2024-02-11
+     pytest.param('svg_inline', '<!-- Generated by graphviz version ',
+                  marks=pytest.mark.xfail('graphviz.version() < (10, 0, 1)',
+                                          reason='needs Graphviz 10 or later'))])
+def test_pipe(dot, plain_text_format, expected_start):
+    result = dot.pipe(format=plain_text_format, encoding='utf-8')
+    assert result.startswith(expected_start)
 
 
 @pytest.mark.parametrize(
